@@ -1,9 +1,11 @@
+from . import agency
 from . import api
 from . import auth
 from . import errors
 from . import institution
 
 __all__ = [
+    'agency',
     'api',
     'auth',
     'errors',
